@@ -15,4 +15,16 @@ denormalize_population <- function(probpars, Pop){
                ncol = ncol(Pop),
                byrow = TRUE)
   return(LL + Pop*(UL-LL))
+}
+
+# Check if a numeric value is within certain bounds
+is_within <- function(x, xmin = 0, xmax = 1, strict = FALSE){
+  out <- is.numeric(x) &&
+    ifelse(strict,
+           x >  xmin,
+           x >= xmin) &&
+  ifelse(strict,
+         x <  xmax,
+         x <= xmax)
+  return(out)
 }
\ No newline at end of file
